@@ -1,11 +1,10 @@
-from fslash.core.option import Nothing_
 import pytest
 from hypothesis import given, strategies as st
-
 from pampy import match, _
 
-from fslash.core import Option, Option_, Some, Nothing, pipe, pipe2
+from fslash.core import Option, Option_, Some, Nothing, Nothing_, pipe, pipe2
 from fslash.builders import option
+from tests.utils import CustomException
 
 
 def test_option_some():
@@ -19,7 +18,7 @@ def test_option_some():
 def test_option_some_iterate():
     xs = Some(42)
 
-    for x in xs:
+    for x in Option.to_list(xs):
         assert x == 42
 
 
@@ -34,9 +33,8 @@ def test_option_none():
 def test_option_nothing_iterate():
     xs = Nothing
 
-    with pytest.raises(Nothing_):
-        for x in xs:
-            pass
+    for x in Option.to_list(xs):
+        assert False
 
 
 def test_option_none_equals_none():
@@ -51,6 +49,7 @@ def test_option_none_not_equals_some():
     ys = Nothing
 
     assert xs != ys
+    assert ys != xs
 
 
 @given(st.one_of(st.integers(), st.text(), st.floats()), st.one_of(st.integers(), st.text(), st.floats()))
@@ -197,7 +196,8 @@ def test_option_of_object_value():
 def test_option_builder_zero():
     @option
     def fn():
-        yield
+        while False:
+            yield
 
     xs = fn()
     assert xs.match(
@@ -310,6 +310,19 @@ def test_option_builder_none_short_circuits():
     ) is None
 
 
+def test_option_builder_throws():
+    error = "do'h"
+    @option
+    def fn():
+        raise CustomException(error)
+        yield
+
+    with pytest.raises(CustomException) as ex:
+        xs = fn()
+
+    assert ex.value.message == error
+
+
 """
 Idea: for applicative
 def gather(a, b):
